@@ -453,7 +453,6 @@ class ErrorCodes(object):
             IdToRemoveIsInvalid = "92025"
 
     class Transaction(object):
-        AdjustmentAmountMustBeGreaterThanZero = "95605"
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
@@ -522,6 +521,7 @@ class ErrorCodes(object):
         PaymentMethodNonceUnknown = "91565"
         PaymentMethodTokenCardTypeIsNotAccepted = "91517"
         PaymentMethodTokenIsInvalid = "91518"
+        ProcessingMerchantCategoryCodeIsInvalid = "915265"
         ProcessorAuthorizationCodeCannotBeSet = "91519"
         ProcessorAuthorizationCodeIsInvalid = "81520"
         ProcessorDoesNotSupportAuths = "915104"
@@ -585,8 +585,17 @@ class ErrorCodes(object):
         TransactionIsNotEligibleForAdjustment = "915219"
         TransactionMustBeInStateAuthorized = "915218"
         TransactionSourceIsInvalid = "915133"
-        TransferTypeIsInvalid = "97501"
+        TransferDetailsAreNotApplicableForThisMerchantAccount = "97511"
         TransferDetailsAreRequired = "97510"
+        TransferReceiverAccountReferenceNumberIsNotValid = "97509"
+        TransferReceiverFirstNameIsNotValid = "97507"
+        TransferReceiverLastNameIsNotValid = "97508"
+        TransferReceiverTaxIdIsNotValid = "97506"
+        TransferSenderAccountReferenceNumberIsNotValid = "97505"
+        TransferSenderFirstNameIsNotValid = "97503"
+        TransferSenderLastNameIsNotValid = "97504"
+        TransferSenderTaxIdIsNotValid = "97502"
+        TransferTypeIsInvalid = "97501"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
